@@ -249,14 +249,6 @@ atk_text_interface_init (AtkTextIface *iface)
 static void
 html_a11y_text_finalize (GObject *obj)
 {
-        HTMLA11YText *ato = HTML_A11Y_TEXT (obj);
-
-        if (ato->util != NULL) {
-                g_object_unref (ato->util);
-                ato->util = NULL;
-        }
-
-        G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
@@ -438,14 +430,10 @@ html_a11y_text_get_text (AtkText *text, gint start_offset, gint end_offset)
 	if (end_offset == -1)
 		end_offset = to->text_len;
 
-	if (start_offset > end_offset)
-		return NULL;
-	if (start_offset < 0)
-		return NULL;
-	if (start_offset > to->text_len)
-		return NULL;
-	if (end_offset > to->text_len)
-		return NULL;
+	g_return_val_if_fail (start_offset <= end_offset, NULL);
+	g_return_val_if_fail (start_offset >= 0, NULL);
+	g_return_val_if_fail (start_offset <= to->text_len, NULL);
+	g_return_val_if_fail (end_offset <= to->text_len, NULL);
 
 	str = html_text_get_text (to, start_offset);
 
