@@ -41,6 +41,7 @@ struct _Link {
 	gint end_offset;
 	gchar *url;
 	gchar *target;
+	gboolean is_visited;  
 };
 
 struct _HTMLTextPangoInfoEntry {
@@ -66,8 +67,13 @@ struct _HTMLPangoAttrFontSize {
 struct _HTMLText {
 	HTMLObject object;
 	
+	/* utf-8 encoded text */
 	gchar   *text;
+
+	/* text length in charactes */
 	guint    text_len;
+
+	/* text length in bytes */
 	guint    text_bytes;
 
 	PangoAttrList    *attr_list;
@@ -117,6 +123,8 @@ HTMLObject       *html_text_new_with_len                 (const gchar        *te
 							  gint                len,
 							  GtkHTMLFontStyle    font_style,
 							  HTMLColor          *color);
+void              html_text_change_set                   (HTMLText           *text,
+							  HTMLChangeFlags     flags);
 void              html_text_queue_draw                   (HTMLText           *text,
 							  HTMLEngine         *engine,
 							  guint               offset,
@@ -216,6 +224,10 @@ void              html_text_add_link_full                (HTMLText           *te
 							  gint                end_index,
 							  gint                start_offset,
 							  gint                end_offset);
+void              html_text_set_link_visited 		 (HTMLText *text, 
+							  gint offset, 
+							  HTMLEngine *engine, 
+							  gboolean is_visited);
 void              html_text_remove_links                 (HTMLText           *text);
 gboolean          html_text_get_link_rectangle           (HTMLText           *text,
 							  HTMLPainter        *painter,
@@ -282,7 +294,8 @@ Link     *html_link_new                 (gchar *url,
 					 guint  start_index,
 					 guint  end_index,
 					 gint   start_offset,
-					 gint   end_offset);
+					 gint   end_offset,
+					 gboolean is_visited);
 Link     *html_link_dup                 (Link  *link);
 void      html_link_free                (Link  *link);
 gboolean  html_link_equal               (Link  *l1,
@@ -294,36 +307,37 @@ void      html_link_set_url_and_target  (Link  *link,
 /*
  * protected
  */
-HTMLTextPangoInfo *html_text_pango_info_new        (gint                   n);
-void               html_text_pango_info_destroy    (HTMLTextPangoInfo     *pi);
-HTMLTextPangoInfo *html_text_get_pango_info        (HTMLText              *text,
-						    HTMLPainter           *painter);
-gint               html_text_pango_info_get_index  (HTMLTextPangoInfo     *pi,
-						    gint                   byte_offset,
-						    gint                   idx);
-PangoAttribute    *html_pango_attr_font_size_new   (GtkHTMLFontStyle       style);
-void               html_pango_attr_font_size_calc  (HTMLPangoAttrFontSize *attr,
-						    HTMLEngine            *e);
-PangoAttrList     *html_text_get_attr_list         (HTMLText              *text,
-						    gint                   start_index,
-						    gint                   end_index);
-void               html_text_calc_text_size        (HTMLText              *t,
-						    HTMLPainter           *painter,
-						    gint                   start_byte_offset,
-						    guint                  len,
-						    HTMLTextPangoInfo     *pi,
-						    GList                 *glyphs,
-						    gint                  *line_offset,
-						    gint                  *width,
-						    gint                  *asc,
-						    gint                  *dsc);
-void               html_text_change_attrs          (PangoAttrList         *attr_list,
-						    GtkHTMLFontStyle       style,
-						    HTMLEngine            *e,
-						    gint                   start_index,
-						    gint                   end_index,
-						    gboolean               avoid_default_size);
-PangoDirection     html_text_get_pango_direction   (HTMLText              *text);
+HTMLTextPangoInfo *html_text_pango_info_new           (gint                   n);
+void               html_text_pango_info_destroy       (HTMLTextPangoInfo     *pi);
+HTMLTextPangoInfo *html_text_get_pango_info           (HTMLText              *text,
+						       HTMLPainter           *painter);
+gint               html_text_pango_info_get_index     (HTMLTextPangoInfo     *pi,
+						       gint                   byte_offset,
+						       gint                   idx);
+PangoAttribute    *html_pango_attr_font_size_new      (GtkHTMLFontStyle       style);
+void               html_pango_attr_font_size_calc     (HTMLPangoAttrFontSize *attr,
+						       HTMLEngine            *e);
+PangoAttrList     *html_text_get_attr_list            (HTMLText              *text,
+						       gint                   start_index,
+						       gint                   end_index);
+void               html_text_calc_text_size           (HTMLText              *t,
+						       HTMLPainter           *painter,
+						       gint                   start_byte_offset,
+						       guint                  len,
+						       HTMLTextPangoInfo     *pi,
+						       GList                 *glyphs,
+						       gint                  *line_offset,
+						       gint                  *width,
+						       gint                  *asc,
+						       gint                  *dsc);
+void               html_text_change_attrs             (PangoAttrList         *attr_list,
+						       GtkHTMLFontStyle       style,
+						       HTMLEngine            *e,
+						       gint                   start_index,
+						       gint                   end_index,
+						       gboolean               avoid_default_size);
+PangoDirection     html_text_get_pango_direction      (HTMLText              *text);
+HTMLDirection      html_text_direction_pango_to_html  (PangoDirection         pdir);
 
 gboolean  html_text_is_line_break                (PangoLogAttr  attr);
 void      html_text_remove_unwanted_line_breaks  (char         *s,
@@ -348,4 +362,8 @@ html_tmp_fix_pango_glyph_string_get_logical_widths (PangoGlyphString *glyphs,
 						    int               length,
 						    int               embedding_level,
 						    int              *logical_widths);
+
+PangoAttrList *html_text_prepare_attrs (HTMLText *text, 
+					HTMLPainter *painter);
+
 #endif /* _HTMLTEXT_H_ */
